<?php

/**
 * PHP Wrapper for Accessing Bomcheck Api
 * @author  Saud Ur Rehman <saud@blubolt.com>
 * www.bomcheck.net
 */
class BomcheckApi
{
	/**
	 * Provides the URL for the API.  The URL is set in the Child wrapper. For example, the Download wrapper would set the URL to https://www.bomcheck.net/api/download.  The Integrate wrapper would set the URL to https://www.bomcheck.net/api/integrate.
	 * @var string
	 */	
	protected $_url;
	
	/**
	 * Allows access to the API. The API key is specified in this Parent wrapper
	 * Text: The Manufacturer's BOMcheck API key.  The Manufacturer must login to their Manufacturer Account on BOMcheck to find out their API key.
	 * @var string
	 */	
	protected $_apikey;	
	
	/** 
	 * FilePath where the response will be saved.  The FilePath is set in the Child wrapper.  Both Child wrappers have a default FilePath setting = tmp/download/
	 * @var string
	 */	
	protected $_filePath;	

	/**
	 * BOMcheck object constructor
	 *
	 * @param string format
	 * @param string format class
	 * @param string supplierDuns
	 * @param string start Date
	 */
	public function __construct($url, $filePath) {
		$this->_url = $url;
		$this->_apikey =  '2a61a1fcb2aecd6907c6c8e8';
		$this->_filePath = $filePath;
	}
	
	/**
	 * BOMcheck destructor
	 */
	public function __destruct() { }
	
	
	/**
	 * Prepares the post data for curl call
	 *
	 * @param array POST Fields
	 */
	protected function preparePostData($postFields) {
		$postFieldsData = array();
		foreach($postFields as $key=>$value) {
			if(!empty($value)){
				$postFieldsData[] = $key.'='.urlencode($value);
			} 
		}
  		$query = implode("&", $postFieldsData);
  		$data['query'] = $query;
  		$data['count'] = count($postFieldsData);
  		return $data;
	}	

	/**
	 * 
	 * Unzip Data
	 */
	protected function unZipData($path, $extractTo) {
        $zip = new ZipArchive;
		if (!$zip) {
			echo "Could not make ZipArchive object.";
			exit;
		}
		$zip->open($path);
		$zip->extractTo($extractTo);
		$zip->close();
		return true;		
	}
	
	/**
	 * 
	 * Send Request
	 */
	protected function sendRequest($data, $fp = null, &$info = null, &$error = null)
	{  
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $this->_url);
        curl_setopt($ch, CURLOPT_HEADER, 0);
        curl_setopt($ch, CURLOPT_TIMEOUT, 0);
        if($fp)
        {
        	curl_setopt($ch, CURLOPT_FILE, $fp);
        }
        curl_setopt($ch, CURLOPT_POSTFIELDS, $data['query']);
        curl_setopt($ch,CURLOPT_POST,count($data['count']));
        $response = curl_exec($ch);
        $info = curl_getinfo($ch);
        $error = curl_error($ch);
        curl_close($ch);
        if($fp)
        {
	        fclose($fp);
		}
        return $response;
	}
}
?>
