<?php
/**
 * PHP Wrapper for Accessing Bomcheck Api
 * @author  Saud Ur Rehman <saud@blubolt.com>
 * www.bomcheck.net
 */
class BomcheckDownload extends BomcheckApi
{	
	/**
	 * Specifies the format of the data to be returned
	 * CSV or XML
	 * @var string
	 */	
	private $_format;
	
	/**
	 * Specifies the Class of the IPC 1752A XML to be returned
	 * C, D or checkDThenC for XML, blank for CSV.  If you specify Class D and the FMD < 100% substances declared then BOMcheck will provide a Class D+C XML. If you specify checkDThenC then BOMcheck will check if FMD is available (and if so provide the Class D XML or Class D+C XML) and if not then check if RCD is available (and if so provide the Class C XML). For example, if a supplier has provided 100% FMD for parts A, B, C, D and only RCD data for parts 1, 2, 3, 4 then BOMcheck will provide two XML files for this supplier in the download - a Class D XML for parts A, B, C, D and a Class C XML for parts 1, 2, 3, 4.
	 * @var string
	 */	
	private $_formatClass;
	
	/**
	 * Option to select data for particular supplier(s)
	 * Either a single BOMcheck supplier code (DUNS number) or multiple BOMcheck supplier codes (DUNS numbers) separated by comma.  For example: 123456789, 987654321, 222222222. 
	 * @var string
	 */
	private $_supplierDuns;
	
	/**
	 * Option to select data for particular part number(s)
	 * Either a single part number or multiple part numbers separated by comma.  Each part number must be in double quotes.  For example: "ABC123","DEF456","XYZ999". 
	 * @var string
	 */		
	private $_partNumbers;
	
	/**
	 * Option to select data that has been approved on BOMcheck after a particular Start Date. 
	 * Date must be provided in YYYY-MM-DD format. 
	 * @var Date
	 */	
	private $_startdate;	
	

	/**
	 * BOMcheck object constructor
	 *
	 * @param string format
	 * @param string format class
	 * @param string supplierDuns
	 * @param string start Date
	 */
	public function __construct($format, $formatClass = null, $supplierDuns = null, $partNumbers = null, $startdate=null)
	{
		parent::__construct('https://www.bomcheck.net/api/download', 'tmp/download/'); // URL must be changed to https://demo.bomcheck.net/api/download if you want to carry out API testing on the demo site. Default FilePath is set to tmp/download/ and must be changed to the location where you want BOMcheck responses to be saved.
		$this->_format =  $format;
		$this->_formatClass = $formatClass;
		$this->_supplierDuns  = $supplierDuns;
		$this->_partNumbers =  $partNumbers;
		$this->_startdate =  $startdate;
	}
	
	/**
	 * BOMcheck destructor
	 */
	public function __destruct() { }
	
	/**
	 * 
	 * Downloads Data
	 */
	public function downloadData($unzip = false)
	{
		
		$path = $this->_filePath;
		$fileName = '/PartsComplianceData_'.date('Y.m.d.h.i.s');
		$fullPath = $path.$fileName; 
		$fp = fopen($fullPath, 'w') or die("can't open file");
		$postFields = array( 'apikey' => $this->_apikey,
							 'format' => $this->_format,
							 'class' => $this->_formatClass,
							 'supplier' => $this->_supplierDuns,
							 'partNumbers' => $this->_partNumbers,
							 'startdate' => $this->_startdate		
                      		);
		$data = $this->preparePostData($postFields);
		
        $info = array();
        $this->sendRequest($data, $fp, $info);
        
        if($info['http_code'] == 200) {
        	if($unzip) {
				$this->unZipData($fullPath, $path);
				unlink($fullPath);
        	} else {
        		rename($fullPath,$fullPath.'.zip');
     			$fileName = $fileName.'.zip';
        	}
        	return true;
        } else {
        	echo file_get_contents($fullPath);
        	unlink($fullPath);
        }
        return false;
	}
	
	//CALLING API
	/* 
	 //Make sure you have right values for $this->_url, $this->_apikey, $this->_filePath
	 	$bomcheck = new BomcheckDownload('CSV',null,'112233448,007321904','"CA-100","1015090AAPC"','2010-12-25');
		$unzip = false;
		if($bomcheck->downloadData($unzip)) {
			echo 'Data downloaded successfully';
		}
	*/	
}
?>
