<?php
/**
 * PHP Wrapper for Accessing Bomcheck Api
 * @author  Saud Ur Rehman <saud@blubolt.com>
 * www.bomcheck.net
 */
class BomcheckIntegration extends BomcheckApi
{	
	/**
	 * Specifies the integration data that you want to receive.
	 * Choose one of the following Actions 'listSubstanceCategories','listExemptions','listSuppliers' or 'listCasNumbers'
	 * @var string
	 */		
	private $_action;
	
	/**
	 * Specifies the type of output that BOMcheck will provide
	 * Choose 'file' or 'content'.  
	 * Default: content
	 * @var string
	 */
	private $_output;	
	

	/**
	 * BOMcheck object constructor
	 *
	 * @param string action
	 */
	public function __construct()
	{	
		parent::__construct('https://www.bomcheck.net/integrate', 'tmp/download/); 
		$this->_action = null;
		$this->_output = "content";  
	}
	
	/**
	 * BOMcheck destructor
	 */
	public function __destruct() { }
	
	/** 
	 * Request Data
	 */
	public function requestData() 
	{	
		if(!$this->_action)
		{
			echo 'Please call one of the action';
			return;
		}

		$fullPath = $this->_filePath.'/'.$this->_action.'.xml';
		$postFields = array( 'apikey' => $this->_apikey,
							 'action' => $this->_action,
							 'output' => $this->_output		
                      		);
		$data = $this->preparePostData($postFields);
		
        $info = array();
        
        $fp = fopen($fullPath, 'w') or die("can't open file");
        $response = $this->sendRequest($data, $fp, $info);
		
        if($info['http_code'] == 200) 
        {
        	return true;
        }
        else {
			echo file_get_contents($fullPath);
        	unlink($fullPath);
        }
        return false;
	}
	
	/** 
	 * List Substance Categories
	 */
	public function listSubstanceCategories()
	{
		$this->_action = "listSubstanceCategories";
		$this->requestData();
		return true;
	}
	
	/** 
	 * List Exemptions
	 */
	public function listExemptions()
	{
		$this->_action = "listExemptions";
		$this->requestData();
		return true;
	}
	
	/** 
	 * List Suppliers
	 */
	public function listSuppliers()
	{
		$this->_action = "listSuppliers";
		$this->requestData();
		return true;
	}
	
	/** 
	 * List CasNumbers
	 */
	public function listCasNumbers()
	{
		$this->_action = "listCasNumbers";
		$this->requestData();
		return true;
	}
	
	/*
	 	//Make sure you have right values for $this->_url, $this->_apikey, $this->_filePath
		$bomcheck = new BomcheckIntegration();
		$bomcheck->listSubstanceCategories();
		$bomcheck->listExemptions();
		$bomcheck->listSuppliers();
		$bomcheck->listCasNumbers();
	 */

}
?>
